#
# Conditional build:
%bcond_with	tests		# build without tests
%bcond_with	build_docs	# build docs instead of pre-packaged files

# NOTE:
# - docs build requires git checkout and (yet) missing sphinxext-opengraph package

Summary:	Cross-platform, fast, feature full, GPU based terminal emulator
Name:		kitty
Version:	0.27.1
Release:	1
# BSD:          docs/_templates/searchbox.html
# zlib:         glfw/
License:	GPLv3 and zlib and BSD
Source0:	https://github.com/kovidgoyal/kitty/releases/download/v%{version}/%{name}-%{version}.tar.xz
# Source0-md5:	3e24876ca288589dfab398de81b02614
# Add AppData manifest file
# * https://github.com/kovidgoyal/kitty/pull/2088
Source1:	%{name}.metainfo.xml
Source2:	%{name}.sh
Source3:	%{name}.fish
%if 0
go mod vendor
tar -caf ~/kitty-vendor.tar.xz vendor
%endif
Source4:	%{name}-%{version}-vendor.tar.xz
# Source4-md5:	f6aac2e7f2b6a58e468a160899d823c2
Patch0:		num-workers.patch
URL:		https://sw.kovidgoyal.net/kitty
BuildRequires:	appstream-glib
BuildRequires:	dbus-devel
BuildRequires:	desktop-file-utils
BuildRequires:	fontconfig-devel
BuildRequires:	gcc
BuildRequires:	gnupg2
BuildRequires:	golang >= 1.20
BuildRequires:	harfbuzz-devel >= 2.2
BuildRequires:	lcms2-devel
BuildRequires:	libcanberra-devel
BuildRequires:	libglvnd-libGL-devel
BuildRequires:	libpng-devel
BuildRequires:	librsync-devel
BuildRequires:	ncurses
BuildRequires:	openssl-devel
BuildRequires:	python3-devel >= 1:3.8
BuildRequires:	python3dist(setuptools)
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 2.023
BuildRequires:	wayland-devel
BuildRequires:	wayland-protocols
BuildRequires:	xorg-lib-libXcursor-devel
BuildRequires:	xorg-lib-libXi-devel
BuildRequires:	xorg-lib-libXinerama-devel
BuildRequires:	xorg-lib-libXrandr-devel
BuildRequires:	xorg-lib-libxkbcommon-x11-devel
BuildRequires:	zlib-devel
%if %{with build_docs}
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(sphinx-copybutton)
BuildRequires:	python3dist(sphinx-inline-tabs)
#BuildRequires:	python3dist(sphinxext-opengraph)
BuildRequires:	sphinx-pdg
%endif
%if %{with tests}
BuildRequires:	/usr/bin/getent
BuildRequires:	/usr/bin/ssh
%endif
Requires:	hicolor-icon-theme
Requires:	python3
Suggests:	%{name}-bash-integration
Suggests:	%{name}-fish-integration
# Terminfo file has been split from the main program and is required for use
# without errors. It has been separated to support SSH into remote machines using
# kitty as per the maintainers suggestion. Install the terminfo file on the remote
# machine.
Requires:	%{name}-terminfo = %{version}-%{release}
# Very weak dependencies, these are required to enable all features of kitty's
# "kittens" functions install separately
Recommends:	python3-pygments
Suggests:	ImageMagick
ExclusiveArch:	%go_arches
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define	specflags	-Wno-array-bounds

%description
- Offloads rendering to the GPU for lower system load and buttery
  smooth scrolling. Uses threaded rendering to minimize input latency.
- Supports all modern terminal features: graphics (images), unicode,
  true-color, OpenType ligatures, mouse protocol, focus tracking,
  bracketed paste and several new terminal protocol extensions.
- Supports tiling multiple terminal windows side by side in different
  layouts without needing to use an extra program like tmux.
- Can be controlled from scripts or the shell prompt, even over SSH.
- Has a framework for Kittens, small terminal programs that can be
  used to extend kitty's functionality. For example, they are used for
  Unicode input, Hints and Side-by-side diff.
- Supports startup sessions which allow you to specify the window/tab
  layout, working directories and programs to run on startup.
- Cross-platform: kitty works on Linux and macOS, but because it uses
  only OpenGL for rendering, it should be trivial to port to other
  Unix-like platforms.
- Allows you to open the scrollback buffer in a separate window using
  arbitrary programs of your choice. This is useful for browsing the
  history comfortably in a pager or editor.
- Has multiple copy/paste buffers, like vim.

%package bash-integration
Summary:	Automatic Bash integration for Kitty Terminal
BuildArch:	noarch

%description bash-integration
Cross-platform, fast, feature full, GPU based terminal emulator.

Bash integration for Kitty Terminal.

%package fish-integration
Summary:	Automatic Fish integration for Kitty Terminal
BuildArch:	noarch

%description fish-integration
Cross-platform, fast, feature full, GPU based terminal emulator.

Fish integration for Kitty Terminal.

%package terminfo
Summary:	The terminfo file for Kitty Terminal
Requires:	ncurses
BuildArch:	noarch

%description    terminfo
Cross-platform, fast, feature full, GPU based terminal emulator.

The terminfo file for Kitty Terminal.

%package doc
Summary:	Documentation for %{name}

%description doc
This package contains the documentation for %{name}.

%prep
%autosetup -p1 -a4

# Changing sphinx theme to classic
sed "s/html_theme = 'furo'/html_theme = 'classic'/" -i docs/conf.py

# Missing in pld
%{__sed} -i -e '/sphinxext.opengraph/d' docs/conf.py

find -type f -name "*.py" | xargs sed -i \
	-e 's|%{_bindir}/env python3|%{__python3}|g' \
	-e 's|%{_bindir}/env python|%{__python3}|g' \
	-e 's|%{_bindir}/env -S kitty|%{_bindir}/kitty|g' \
	%{nil}

# non-executable-script
sed -e "s/f.endswith('\.so')/f.endswith('\.so') or f.endswith('\.py')/g" -i setup.py

# script-without-shebang '__init__.py'
find -type f -name "*.py*" | xargs chmod a-x

%build
%if %{with build_docs}
%{__python3} setup.py build
%{__make} -C docs man html
%endif

%install
rm -rf $RPM_BUILD_ROOT
%set_build_flags
export CC="%{__cc}"
export CXX="%{__cxx}"
export GOCACHE=%go_cachedir
export NUM_WORKERS=1
# unset PWD for https://github.com/kovidgoyal/kitty/issues/6051
unset PWD
# NOTE: setup.py is not regular setuptools setup.py
%{__python3} setup.py linux-package \
    --libdir-name=%{_lib} \
    --prefix=$RPM_BUILD_ROOT%{_prefix} \
    --update-check-interval=0 \
    --verbose \
    --debug \
    --shell-integration "disabled" \
    %{nil}

install -Dp %{SOURCE1} $RPM_BUILD_ROOT%{_metainfodir}/%{name}.metainfo.xml
install -Dp %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/%{name}.sh
install -Dp %{SOURCE3} $RPM_BUILD_ROOT%{fish_compdir}/%{name}.fish

sed 's|KITTY_INSTALLATION_DIR=.*|KITTY_INSTALLATION_DIR="%{_libdir}/%{name}"|' \
 -i $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/%{name}.sh
sed 's|set -l KITTY_INSTALLATION_DIR .*|set -l KITTY_INSTALLATION_DIR "%{_libdir}/%{name}"|' \
 -i $RPM_BUILD_ROOT%{fish_compdir}/%{name}.fish

# script-without-shebang '__init__.py'
find $RPM_BUILD_ROOT -type f -name "*.py*" ! -name askpass.py | xargs chmod a-x

# rpmlint fixes
rm $RPM_BUILD_ROOT%{_docdir}/%{name}/html/.buildinfo \
	$RPM_BUILD_ROOT%{_docdir}/%{name}/html/.nojekyll

%if %{with tests}
# Some tests ignores PATH env...
install -d kitty/launcher
ln -s $RPM_BUILD_ROOT%{_bindir}/%{name} kitty/launcher
export PATH=$RPM_BUILD_ROOT%{_bindir}:$PATH
%{__python3} setup.py test          \
    --prefix=$RPM_BUILD_ROOT%{_prefix}
%endif

appstream-util validate-relax --nonet $RPM_BUILD_ROOT%{_metainfodir}/*.xml
desktop-file-validate $RPM_BUILD_ROOT%{_desktopdir}/*.desktop

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc LICENSE
%attr(755,root,root) %{_bindir}/kitten
%attr(755,root,root) %{_bindir}/kitty
%{_desktopdir}/kitty-open.desktop
%{_desktopdir}/kitty.desktop
%{_iconsdir}/hicolor/*/*/kitty.{png,svg}
%{_metainfodir}/kitty.metainfo.xml
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.py
%{_libdir}/%{name}/__pycache__
%{_libdir}/%{name}/kittens
%{_libdir}/%{name}/kitty
%{_libdir}/%{name}/logo
%{_libdir}/%{name}/shell-integration
%{_libdir}/%{name}/terminfo
%{_mandir}/man1/kitty.1*
%{_mandir}/man5/kitty.conf.5*

%files bash-integration
%defattr(644,root,root,755)
/etc/profile.d/kitty.sh

%files fish-integration
%defattr(644,root,root,755)
%{fish_compdir}/kitty.fish

%files terminfo
%defattr(644,root,root,755)
%doc LICENSE
%{_datadir}/terminfo/x/xterm-kitty

%files doc
%defattr(644,root,root,755)
%doc CONTRIBUTING.md CHANGELOG.rst INSTALL.md LICENSE
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/html
%changelog
* Thu Feb 23 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/kitty.git;a=log;h=master

* Thu Feb 23 2023 Elan Ruusamäe <glen@pld-linux.org> 2bda90d
- Unset PWD for go build failure

* Thu Feb 23 2023 Elan Ruusamäe <glen@pld-linux.org> bf53b96
- Set GOCACHE inside build dir

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 13231ae
- Disable tests; Needs more work

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 53c6aa0
- Rename appdata to metainfo

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 699a0af
- Go -mod=vendor patching is not needed

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 87b69c7
- Add build_docs bulding

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 7a7cc8c
- Add setup.py notice

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> de67fa1
- Docs are always present

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 1cb4ff0
- Revert unwanted build flags cleanup

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> cd0a3d5
- Set ExclusiveArch because requires go to build

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> d90a30c
- Run adapter

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 6d4d544
- kitty.appdata.xml is stored in git repo

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 7749832
- Add md5 for go vendor

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 56fd027
- Release 1; builds with cleanbuild

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 08146ad
- Verbose and greppable files

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> e4747d6
- Package kitty executable

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> b3df646
- Fix doc bcond name

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 31349ff
- Bump rpmbuild(macros) >= 2.023 for _metainfodir macro

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 4925732
- Add go vendor tarball

* Wed Feb 22 2023 Elan Ruusamäe <glen@pld-linux.org> 946e1d3
- Kitty requires golang 1.20

